@@ -21,7 +21,7 @@ using namespace KUserFeedback;
 class FeedbackConfigTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         QStandardPaths::setTestModeEnabled(true);
